@@ -10,15 +10,15 @@ assign(GITLAB_CON, NULL, gitlabr_env)
 #' in a call to \code{\link{gitlab}}
 #' 
 #' @param gitlab_con A function used for gitlab API calls, such
-#' as \code{\link{gitlab}} or as returned by \code{\link{gitlab_connection}}.
+#' as \code{\link{gitlab}} or as returned by \code{\link{gl_connection}}.
 #' @param ... if gitlab_con is NULL, a new connection is created used the parameters
-#' is ... using \code{\link{gitlab_connection}}
+#' is ... using \code{\link{gl_connection}}
 #' 
 #' @export 
 set_gitlab_connection <- function(gitlab_con = NULL, ...) {
   stopifnot(is.null(gitlab_con) || is.function(gitlab_con))
   if (is.null(gitlab_con) && length(list(...)) > 0) {
-    gitlab_con <- gitlab_connection(...)
+    gitlab_con <- gl_connection(...)
   }
   assign(GITLAB_CON, gitlab_con, gitlabr_env)
 }
